@@ -89,9 +89,7 @@ class OpenPR:
             title = _ask_for_title()
 
         base_branch = self._ask_for_base_branch()
-        pr_body = self._ask_for_description("", base_branch)
-
-        body = f"{link} \n\n {pr_body}"
+        body = self._ask_for_description("", base_branch=base_branch, link=link)
 
         is_draft = prompt_utils.ask_confirm(
             "Do you want to open the pull request as a draft?", default=False
@@ -115,7 +113,7 @@ class OpenPR:
             AskReview(self._project, self._config, self._tokens).run()
 
     def _edit_pr(self, pr):
-        pr_body = self._ask_for_description(pr.body, pr.base.ref)
+        pr_body = self._ask_for_description(pr.body)
         pr.edit(body=pr_body)
         logger.info("Pull request modified")
 
@@ -125,20 +123,30 @@ class OpenPR:
         )
         return branch
 
-    def _ask_for_description(self, pr_body, base_branch):
-        if pr_body == "" and self._config.user["use_commits_in_pr_body"]:
-            commit_list = get_commit_logs(base_branch)
-            commit_list.reverse()
-            pr_body = "\n---\n".join(commit_list)
-        input(
-            "Enter the description of the pull request. Pressing enter will open the default editor"
-        )
+    def _ask_for_description(self, pr_body, **opts):
+        link = opts.get("link")
+        base_branch = opts.get("base_branch")
+        if pr_body == "":
+            if link:
+                pr_body = link + "\n\n"
+            try:
+                with open("pull_request_template.md", "r") as f:
+                    pr_body = pr_body + f.read() + "\n"
+            except Exception:
+                pass
+            if base_branch and self._config.user["use_commits_in_pr_body"]:
+                commit_list = get_commit_logs(base_branch)
+                commit_list.reverse()
+                pr_body = pr_body + "\n---\n".join(commit_list)
+                input(
+                    "Enter the description of the pull request. Pressing enter will open the default editor"
+                )
         description = prompt_utils.ask_questions_editor(
             "Enter the description of the PR: ", pr_body
         )
         if description == "":
             logger.warning("The description of the pull request cannot be empty")
-            return self._ask_for_description(pr_body, base_branch)
+            return self._ask_for_description(pr_body)
         return description
 
 
