@@ -52,3 +52,17 @@ def ask_choices(question_text, choices, default_text=""):
 
     answer = prompt(questions)
     return answer["value"]
+
+
+def ask_multiple_choices(question_text, choices):
+    questions = [
+        {
+            "type": "checkbox",
+            "name": "values",
+            "message": question_text,
+            "choices": [{"name": choice} for choice in choices],
+        }
+    ]
+
+    answer = prompt(questions)
+    return answer["values"]
